@@ -72,6 +72,10 @@ SDL_CONTROLLER_TYPE_VIRTUAL = 6
 SDL_CONTROLLER_TYPE_PS5 = 7
 SDL_CONTROLLER_TYPE_AMAZON_LUNA = 8
 SDL_CONTROLLER_TYPE_GOOGLE_STADIA = 9
+SDL_CONTROLLER_TYPE_NVIDIA_SHIELD = 10
+SDL_CONTROLLER_TYPE_NINTENDO_SWITCH_JOYCON_LEFT = 11
+SDL_CONTROLLER_TYPE_NINTENDO_SWITCH_JOYCON_RIGHT = 12
+SDL_CONTROLLER_TYPE_NINTENDO_SWITCH_JOYCON_PAIR = 13
 
 SDL_GameControllerAxis = c_int
 SDL_CONTROLLER_AXIS_INVALID = -1
