@@ -48,7 +48,10 @@ __all__ = [
     "SDL_HINT_JOYSTICK_HIDAPI_GAMECUBE",
     "SDL_HINT_JOYSTICK_GAMECUBE_RUMBLE_BRAKE",
     "SDL_HINT_JOYSTICK_HIDAPI_JOY_CONS",
+    "SDL_HINT_JOYSTICK_HIDAPI_COMBINE_JOY_CONS",
     "SDL_HINT_JOYSTICK_HIDAPI_LUNA",
+    "SDL_HINT_JOYSTICK_HIDAPI_NINTENDO_CLASSIC",
+    "SDL_HINT_JOYSTICK_HIDAPI_SHIELD",
     "SDL_HINT_JOYSTICK_HIDAPI_PS4",
     "SDL_HINT_JOYSTICK_HIDAPI_PS4_RUMBLE",
     "SDL_HINT_JOYSTICK_HIDAPI_PS5",
@@ -58,6 +61,8 @@ __all__ = [
     "SDL_HINT_JOYSTICK_HIDAPI_STEAM",
     "SDL_HINT_JOYSTICK_HIDAPI_SWITCH",
     "SDL_HINT_JOYSTICK_HIDAPI_SWITCH_HOME_LED",
+    "SDL_HINT_JOYSTICK_HIDAPI_JOYCON_HOME_LED",
+    "SDL_HINT_JOYSTICK_HIDAPI_SWITCH_PLAYER_LED",
     "SDL_HINT_JOYSTICK_HIDAPI_XBOX",
     "SDL_HINT_JOYSTICK_RAWINPUT",
     "SDL_HINT_JOYSTICK_RAWINPUT_CORRELATE_XINPUT",
@@ -72,6 +77,7 @@ __all__ = [
     "SDL_HINT_LINUX_JOYSTICK_DEADZONES",
     "SDL_HINT_MAC_BACKGROUND_APP",
     "SDL_HINT_MAC_CTRL_CLICK_EMULATE_RIGHT_CLICK",
+    "SDL_HINT_MAC_OPENGL_ASYNC_DISPATCH",
     "SDL_HINT_MOUSE_DOUBLE_CLICK_RADIUS",
     "SDL_HINT_MOUSE_DOUBLE_CLICK_TIME",
     "SDL_HINT_MOUSE_FOCUS_CLICKTHROUGH",
@@ -80,6 +86,7 @@ __all__ = [
     "SDL_HINT_MOUSE_RELATIVE_MODE_WARP",
     "SDL_HINT_MOUSE_RELATIVE_SCALING",
     "SDL_HINT_MOUSE_RELATIVE_SPEED_SCALE",
+    "SDL_HINT_MOUSE_RELATIVE_WARP_MOTION",
     "SDL_HINT_MOUSE_TOUCH_EVENTS",
     "SDL_HINT_MOUSE_AUTO_CAPTURE",
     "SDL_HINT_NO_SIGNAL_HANDLERS",
@@ -257,6 +264,7 @@ SDL_HINT_MOUSE_RELATIVE_MODE_CENTER = b"SDL_MOUSE_RELATIVE_MODE_CENTER"
 SDL_HINT_MOUSE_RELATIVE_MODE_WARP = b"SDL_MOUSE_RELATIVE_MODE_WARP"
 SDL_HINT_MOUSE_RELATIVE_SCALING = b"SDL_MOUSE_RELATIVE_SCALING"
 SDL_HINT_MOUSE_RELATIVE_SPEED_SCALE = b"SDL_MOUSE_RELATIVE_SPEED_SCALE"
+SDL_HINT_MOUSE_RELATIVE_WARP_MOTION = b"SDL_MOUSE_RELATIVE_WARP_MOTION"
 SDL_HINT_MOUSE_TOUCH_EVENTS = b"SDL_MOUSE_TOUCH_EVENTS"
 SDL_HINT_TOUCH_MOUSE_EVENTS = b"SDL_TOUCH_MOUSE_EVENTS"
 
@@ -278,7 +286,10 @@ SDL_HINT_JOYSTICK_HIDAPI_CORRELATE_XINPUT = b"SDL_JOYSTICK_HIDAPI_CORRELATE_XINP
 SDL_HINT_JOYSTICK_HIDAPI_GAMECUBE = b"SDL_JOYSTICK_HIDAPI_GAMECUBE"
 SDL_HINT_JOYSTICK_GAMECUBE_RUMBLE_BRAKE = b"SDL_JOYSTICK_GAMECUBE_RUMBLE_BRAKE"
 SDL_HINT_JOYSTICK_HIDAPI_JOY_CONS = b"SDL_JOYSTICK_HIDAPI_JOY_CONS"
+SDL_HINT_JOYSTICK_HIDAPI_COMBINE_JOY_CONS = b"SDL_JOYSTICK_HIDAPI_COMBINE_JOY_CONS"
 SDL_HINT_JOYSTICK_HIDAPI_LUNA = b"SDL_JOYSTICK_HIDAPI_LUNA"
+SDL_HINT_JOYSTICK_HIDAPI_NINTENDO_CLASSIC = b"SDL_JOYSTICK_HIDAPI_NINTENDO_CLASSIC"
+SDL_HINT_JOYSTICK_HIDAPI_SHIELD = b"SDL_JOYSTICK_HIDAPI_SHIELD"
 SDL_HINT_JOYSTICK_HIDAPI_PS4 = b"SDL_JOYSTICK_HIDAPI_PS4"
 SDL_HINT_JOYSTICK_HIDAPI_PS4_RUMBLE = b"SDL_JOYSTICK_HIDAPI_PS4_RUMBLE"
 SDL_HINT_JOYSTICK_HIDAPI_PS5 = b"SDL_JOYSTICK_HIDAPI_PS5"
@@ -288,6 +299,8 @@ SDL_HINT_JOYSTICK_HIDAPI_STADIA = b"SDL_JOYSTICK_HIDAPI_STADIA"
 SDL_HINT_JOYSTICK_HIDAPI_STEAM = b"SDL_JOYSTICK_HIDAPI_STEAM"
 SDL_HINT_JOYSTICK_HIDAPI_SWITCH = b"SDL_JOYSTICK_HIDAPI_SWITCH"
 SDL_HINT_JOYSTICK_HIDAPI_SWITCH_HOME_LED = b"SDL_JOYSTICK_HIDAPI_SWITCH_HOME_LED"
+SDL_HINT_JOYSTICK_HIDAPI_JOYCON_HOME_LED = b"SDL_JOYSTICK_HIDAPI_JOYCON_HOME_LED"
+SDL_HINT_JOYSTICK_HIDAPI_SWITCH_PLAYER_LED = b"SDL_JOYSTICK_HIDAPI_SWITCH_PLAYER_LED"
 SDL_HINT_JOYSTICK_HIDAPI_XBOX = b"SDL_JOYSTICK_HIDAPI_XBOX"
 SDL_HINT_JOYSTICK_RAWINPUT = b"SDL_JOYSTICK_RAWINPUT"
 SDL_HINT_JOYSTICK_RAWINPUT_CORRELATE_XINPUT = b"SDL_JOYSTICK_RAWINPUT_CORRELATE_XINPUT"
@@ -307,6 +320,7 @@ SDL_HINT_LINUX_JOYSTICK_CLASSIC = b"SDL_LINUX_JOYSTICK_CLASSIC"
 SDL_HINT_LINUX_JOYSTICK_DEADZONES = b"SDL_LINUX_JOYSTICK_DEADZONES"
 SDL_HINT_MAC_BACKGROUND_APP = b"SDL_MAC_BACKGROUND_APP"
 SDL_HINT_MAC_CTRL_CLICK_EMULATE_RIGHT_CLICK = b"SDL_MAC_CTRL_CLICK_EMULATE_RIGHT_CLICK"
+SDL_HINT_MAC_OPENGL_ASYNC_DISPATCH = b"SDL_MAC_OPENGL_ASYNC_DISPATCH"
 SDL_HINT_RPI_VIDEO_LAYER = b"SDL_RPI_VIDEO_LAYER"
 SDL_HINT_RENDER_DIRECT3D11_DEBUG = b"SDL_RENDER_DIRECT3D11_DEBUG"
 SDL_HINT_RENDER_DIRECT3D_THREADSAFE = b"SDL_RENDER_DIRECT3D_THREADSAFE"
