@@ -53,8 +53,10 @@ def with_sdl_gl(with_sdl):
 def window(with_sdl):
     flag = sdl2.SDL_WINDOW_BORDERLESS
     w = sdl2.SDL_CreateWindow(b"Test", 10, 40, 12, 13, flag)
-    assert SDL_GetError() == b""
-    assert isinstance(w.contents, sdl2.SDL_Window)
+    if not isinstance(w.contents, sdl2.SDL_Window):
+        assert SDL_GetError() == b""
+        assert isinstance(w.contents, sdl2.SDL_Window)
+    sdl2.SDL_ClearError()
     yield w
     sdl2.SDL_DestroyWindow(w)
 
@@ -62,8 +64,10 @@ def window(with_sdl):
 def decorated_window(with_sdl):
     flag = sdl2.SDL_WINDOW_RESIZABLE
     w = sdl2.SDL_CreateWindow(b"Test", 10, 40, 12, 13, flag)
-    assert SDL_GetError() == b""
-    assert isinstance(w.contents, sdl2.SDL_Window)
+    if not isinstance(w.contents, sdl2.SDL_Window):
+        assert SDL_GetError() == b""
+        assert isinstance(w.contents, sdl2.SDL_Window)
+    sdl2.SDL_ClearError()
     yield w
     sdl2.SDL_DestroyWindow(w)
 
@@ -71,13 +75,23 @@ def decorated_window(with_sdl):
 def gl_window(with_sdl_gl):
     flag = sdl2.SDL_WINDOW_OPENGL
     w = sdl2.SDL_CreateWindow(b"OpenGL", 10, 40, 12, 13, flag)
-    assert SDL_GetError() == b""
+    if not isinstance(w.contents, sdl2.SDL_Window):
+        assert SDL_GetError() == b""
+        assert isinstance(w.contents, sdl2.SDL_Window)
+    sdl2.SDL_ClearError()
     ctx = sdl2.SDL_GL_CreateContext(w)
     assert SDL_GetError() == b""
     yield (w, ctx)
     sdl2.SDL_GL_DeleteContext(ctx)
     sdl2.SDL_DestroyWindow(w)
 
+def _create_window(name, h, w, x, y, flags):
+    window = sdl2.SDL_CreateWindow(name, h, w, x, y, flags)
+    if not isinstance(window.contents, sdl2.SDL_Window):
+        assert SDL_GetError() == b""
+        assert isinstance(window.contents, sdl2.SDL_Window)
+    sdl2.SDL_ClearError()
+    return window
 
 # Test custom macros
 
@@ -334,8 +348,9 @@ def test_GetDisplayInfo(with_sdl):
 def test_SDL_CreateDestroyWindow(with_sdl):
     flag = sdl2.SDL_WINDOW_BORDERLESS
     window = sdl2.SDL_CreateWindow(b"Test", 10, 40, 12, 13, flag)
-    assert SDL_GetError() == b""
-    assert isinstance(window.contents, sdl2.SDL_Window)
+    if not isinstance(window.contents, sdl2.SDL_Window):
+        assert SDL_GetError() == b""
+        assert isinstance(window.contents, sdl2.SDL_Window)
     sdl2.SDL_DestroyWindow(window)
 
 @pytest.mark.skip("not implemented")
@@ -343,6 +358,24 @@ def test_SDL_CreateWindowFrom(with_sdl):
     # No obvious cross-platform way to test this
     pass
 
+@pytest.mark.skipif(sdl2.dll.version < 2240, reason="not available")
+def test_SDL_GetPointDisplayIndex(with_sdl):
+    for index in range(sdl2.SDL_GetNumVideoDisplays()):
+        bounds = rect.SDL_Rect()
+        ret = sdl2.SDL_GetDisplayUsableBounds(index, byref(bounds))
+        assert ret == 0
+        p = sdl2.SDL_Point(bounds.x + 50, bounds.y + 50)
+        assert sdl2.SDL_GetPointDisplayIndex(p) == index
+
+@pytest.mark.skipif(sdl2.dll.version < 2240, reason="not available")
+def test_SDL_GetRectDisplayIndex(with_sdl):
+    for index in range(sdl2.SDL_GetNumVideoDisplays()):
+        bounds = rect.SDL_Rect()
+        ret = sdl2.SDL_GetDisplayUsableBounds(index, byref(bounds))
+        assert ret == 0
+        r = sdl2.SDL_Rect(bounds.x + 50, bounds.y + 50, 10, 10)
+        assert sdl2.SDL_GetRectDisplayIndex(r) == index
+
 def test_SDL_GetWindowDisplayIndex(window):
     numdisplays = sdl2.SDL_GetNumVideoDisplays()
     dindex = sdl2.SDL_GetWindowDisplayIndex(window)
@@ -353,8 +386,9 @@ def test_SDL_GetWindowDisplayMode(window):
     # NOTE: Gets fullscreen mode of parent display, not size of window
     dmode = sdl2.SDL_DisplayMode()
     ret = sdl2.SDL_GetWindowDisplayMode(window, byref(dmode))
-    assert SDL_GetError() == b""
-    assert ret == 0
+    if ret != 0:
+        assert SDL_GetError() == b""
+        assert ret == 0
     assert dmode.w > 0
     assert dmode.h > 0
 
@@ -368,8 +402,9 @@ def test_SDL_SetWindowDisplayMode(window):
     sdl2.SDL_SetWindowDisplayMode(window, dmode)
     wmode = sdl2.SDL_DisplayMode()
     ret = sdl2.SDL_GetWindowDisplayMode(window, byref(wmode))
-    assert SDL_GetError() == b""
-    assert ret == 0
+    if ret != 0:
+        assert SDL_GetError() == b""
+        assert ret == 0
     assert dmode == wmode
 
 @pytest.mark.skipif(sdl2.dll.version < 2018, reason="not available")
@@ -442,7 +477,7 @@ def test_SDL_GetSetWindowData(window):
 
 @pytest.mark.xfail(DRIVER_X11, reason="Wonky with some window managers")
 def test_SDL_GetSetWindowPosition(with_sdl):
-    window = sdl2.SDL_CreateWindow(b"Test", 10, 200, 10, 10, 0)
+    window = _create_window(b"Test", 10, 200, 10, 10, 0)
     px, py = c_int(0), c_int(0)
     sdl2.SDL_GetWindowPosition(window, byref(px), byref(py))
     assert (px.value, py.value) == (10, 200)
@@ -682,7 +717,7 @@ def test_SDL_GetGrabbedWindow(window):
 def test_SDL_GetSetWindowMouseRect(with_sdl):
     flags = sdl2.SDL_WINDOW_BORDERLESS
     bounds_in = rect.SDL_Rect(0, 0, 100, 50)
-    window = sdl2.SDL_CreateWindow(b"Test", 200, 200, 200, 200, flags)
+    window = _create_window(b"Test", 200, 200, 200, 200, flags)
     # Try setting a mouse boundary
     ret = sdl2.SDL_SetWindowMouseRect(window, byref(bounds_in))
     assert SDL_GetError() == b""
@@ -812,7 +847,7 @@ def test_SDL_GL_LoadUnloadLibrary(with_sdl):
 
 @pytest.mark.skipif(DRIVER_DUMMY, reason="Doesn't work with dummy driver")
 def test_SDL_GL_CreateDeleteContext(with_sdl_gl):
-    window = sdl2.SDL_CreateWindow(
+    window = _create_window(
         b"OpenGL", 10, 40, 32, 24, sdl2.SDL_WINDOW_OPENGL
     )
     ctx = sdl2.SDL_GL_CreateContext(window)
@@ -837,7 +872,7 @@ def test_SDL_GL_ExtensionSupported(gl_window):
 @pytest.mark.skipif(DRIVER_DUMMY, reason="Doesn't work with dummy driver")
 def test_SDL_GL_GetSetResetAttribute(with_sdl_gl):
     # Create a context and get its bit depth
-    window = sdl2.SDL_CreateWindow(
+    window = _create_window(
         b"OpenGL", 10, 40, 12, 13, sdl2.SDL_WINDOW_OPENGL
     )
     ctx = sdl2.SDL_GL_CreateContext(window)
@@ -845,15 +880,19 @@ def test_SDL_GL_GetSetResetAttribute(with_sdl_gl):
     ret = sdl2.SDL_GL_GetAttribute(sdl2.SDL_GL_DOUBLEBUFFER, byref(bufstate))
     sdl2.SDL_GL_DeleteContext(ctx)
     sdl2.SDL_DestroyWindow(window)
-    assert SDL_GetError() == b""
-    assert ret == 0
+    if ret != 0:
+        assert SDL_GetError() == b""
+        assert ret == 0
+    sdl2.SDL_ClearError()
     # Try setting a different GL bit depth
     new_bufstate = 0 if bufstate.value == 1 else 1
     sdl2.SDL_GL_SetAttribute(sdl2.SDL_GL_DOUBLEBUFFER, new_bufstate)
-    assert SDL_GetError() == b""
-    assert ret == 0
+    if ret != 0:
+        assert SDL_GetError() == b""
+        assert ret == 0
+    sdl2.SDL_ClearError()
     # Create a new context to see if it's using the new bit depth 
-    window = sdl2.SDL_CreateWindow(
+    window = _create_window(
         b"OpenGL", 10, 40, 12, 13, sdl2.SDL_WINDOW_OPENGL
     )
     ctx = sdl2.SDL_GL_CreateContext(window)
@@ -861,13 +900,15 @@ def test_SDL_GL_GetSetResetAttribute(with_sdl_gl):
     ret = sdl2.SDL_GL_GetAttribute(sdl2.SDL_GL_DOUBLEBUFFER, byref(val))
     sdl2.SDL_GL_DeleteContext(ctx)
     sdl2.SDL_DestroyWindow(window)
-    assert SDL_GetError() == b""
-    assert ret == 0
+    if ret != 0:
+        assert SDL_GetError() == b""
+        assert ret == 0
+    sdl2.SDL_ClearError()
     assert bufstate.value != val.value
     assert val.value == new_bufstate
     # Try resetting the context and see if it goes back to the original depth
     sdl2.SDL_GL_ResetAttributes()
-    window = sdl2.SDL_CreateWindow(
+    window = _create_window(
         b"OpenGL", 10, 40, 12, 13, sdl2.SDL_WINDOW_OPENGL
     )
     ctx = sdl2.SDL_GL_CreateContext(window)
